# Testing basic integration of the package into Plone
from collective.carousel.tests.base import TestCase
from plone.portlets.interfaces import IPortletType
from zope.component import getUtility


class CarouselTestCase(TestCase):

    def test_js_available(self):
        jsreg = getattr(self.portal, 'portal_javascripts')
        script_ids = jsreg.getResourceIds()
        self.failUnless('++resource++plone.app.jquerytools.plugins.js'
                        in script_ids)
        self.failUnless(
            '++resource++collective.carousel/carousel.js' in script_ids)

    def test_css_available(self):
        cssreg = getattr(self.portal, 'portal_css')
        stylesheets_ids = cssreg.getResourceIds()
        self.failUnless(
            '++resource++collective.carousel/carousel.css' in stylesheets_ids)

    def test_collections_carouselable(self):
        from collective.carousel.interfaces import ICarouselProvider
        self.setRoles('Manager', )

        self.folder.invokeFactory('Collection', 'test-collection')
        carouselable_col = getattr(self.folder, 'test-collection')
        self.failUnless(ICarouselProvider.providedBy(carouselable_col))

    def test_portlet_type_registered(self):
        portlet = getUtility(IPortletType, name='portlet.Carousel')
        self.assertEquals(portlet.addview, 'portlet.Carousel')


def test_suite():
    from unittest import defaultTestLoader
    return defaultTestLoader.loadTestsFromName(__name__)



from Products.ATContentTypes.interface import IATContentType
from Products.ATReferenceBrowserWidget.ATReferenceBrowserWidget import ReferenceBrowserWidget
from Products.Archetypes.public import ReferenceField
from archetypes.schemaextender.field import ExtensionField
from archetypes.schemaextender.interfaces import IBrowserLayerAwareExtender
from archetypes.schemaextender.interfaces import ISchemaExtender
from collective.carousel.interfaces import ICollectiveCarouselLayer
from zope.component import adapts
from zope.i18nmessageid import MessageFactory
from zope.interface import implements

_ = MessageFactory('collective.carousel')


class CarouselProviderField(ExtensionField, ReferenceField):
    """A field, storing reference to an object, providing content for carousel.
    """


class ContentTypeExtender(object):
    adapts(IATContentType)
    implements(ISchemaExtender, IBrowserLayerAwareExtender)
    layer = ICollectiveCarouselLayer

    _fields = [
        CarouselProviderField("carouselprovider",
            schemata = "settings",
            # the field accepts Collections only atm.
            # Would be cool to have ATRBW to be able to select items by
            # interface with something like 'allowed_interfaces'
            allowed_types = ('Topic', 'Collection',),
            relationship = 'Carousel',
            languageIndependent = True,
            multiValued = True,
            widget = ReferenceBrowserWidget(
                label = _(u"label_carouselprovider_title",
                    default=u"Carousel object."),
                description = _(u"help_carouselprovider",
                    default=u"Object providing items (content) for carousel."),
                ),
            ),
        ]

    def __init__(self, context):
        self.context = context

    def getFields(self):
        return self._fields



from zope.interface import directlyProvides
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleVocabulary
from plone.app.imaging.utils import getAllowedSizes


def ImageScaleVocabulary(context):
    allowed_sizes = getAllowedSizes()
    items = [(u'%s(%s, %s)' % (key, value[0], value[1]), key)
             for key, value in allowed_sizes.items() if allowed_sizes]
    return SimpleVocabulary.fromItems(items)

directlyProvides(ImageScaleVocabulary, IVocabularyFactory)



from setuptools import setup, find_packages

version = '1.7'

setup(
    name='collective.carousel',
    version=version,
    description="Add-on for having Collections' results presented as a nice carousel",
    long_description=open("README.rst").read() + "\n" + open("CHANGES.rst").read(),
    classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords='plone zope collection carousel',
    author='Jarn [Denys Mishunov]',
    author_email='info@jarn.com',
    url='https://github.com/collective/collective.carousel',
    license='GPL',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['collective'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'archetypes.schemaextender',
        'plone.app.jquerytools',
        'plone.portlet.collection',
    ],
    extras_require={'test': [
        'Products.PloneTestCase',
        'collective.testcaselayer'
    ]},
    entry_points="""
        [z3c.autoinclude.plugin]
        target = plone
    """,
)
